# Documentation string. I wonder what ever refers to it? 

__doc__ = """ZFDocument product module.

This module provides the methods and classes that Zope needs for the product. 
__init__.py is responsible for registering these methods and classes.

See README.txt for more details."""

# Version string. Usually updated automatically by CVS. 

__version__ = '0.1' # I used to wonder whether Zope checked these. Nope. 

# Now, you can compress these imports down to three lines, but that makes it 
# harder to document it as you go. Here's the long-winded version: 

from Globals import HTML, HTMLFile
from Globals import MessageDialog
from Globals import Persistent

import OFS.SimpleItem
import Acquisition
import AccessControl.Role

from OFS.DTMLDocument import DTMLDocument
from urllib           import quote, unquote

import re
import string
from xmlrpclib import True, False, Server
from PikeCompatibility import PikeEdit

"""Step #1: Provide "constructors" for Zope's management interface. 
__init__ is all very well and good for Python, but doesn't provide 
a nice HTML interface or accept arguments from an HTTP request, so 
you need to provide some functions to act as a middle-man between 
Zope and your class.

Use HTMLFile to produce a [pseudo-]function which hands back an 
appropriate DTML document based on a file sitting in your product 
directory. 
"""

"""Step #2: Provide the class for your ZFDocument object."""

class ZFDocument(DTMLDocument, PikeEdit): 
    """ZFDocument object. 
    
    This is an attempt at writing a product from scratch using mostly 
    Python instead of ZClasses. We'll see how it all goes.
    """
    meta_type = 'ZFDocument' # what do people think they're adding? 

default_zfdocument = """<dtml-var standard_html_header>
<h2><dtml-var title_or_id></h2>
<p>
This is the <dtml-var document_id> Document 
</p>
<dtml-if "may_edit(REQUEST)">
<dtml-var "edit_in_browser_button(REQUEST)">
<dtml-var "edit_in_pike_button(REQUEST)">
</dtml-if>
<dtml-var standard_html_footer>"""

def manage_addZFDocument(self, id, title='', file='', REQUEST=None, submit=None):
    """Add a ZFDocument object with the contents of file. If
    'file' is empty, default text is used.
    """
    if type(file) is not type(''): file=file.read()
    if not file:
        file = default_zfdocument
    ob=ZFDocument(file, __name__=id)
    ob.title=title
    id=self._setObject(id, ob)

    if REQUEST is not None:
        try: u=self.DestinationURL()
        except: u=REQUEST['URL1']
        if submit==" Add and Edit ": u="%s/%s" % (u,quote(id))
        REQUEST.RESPONSE.redirect(u+'/manage_main')
    return ''

manage_addZFDocumentForm=HTMLFile('zfdocAdd', globals())
